@@ -1,8 +1,3 @@
-# Copyright (c) 2016 CentralNic Ltd. All rights reserved. This program is
-# free software; you can redistribute it and/or modify it under the same
-# terms as Perl itself.
-# 
-# $Id: Transfer.pm,v 1.3 2011/12/03 11:44:52 gavin Exp $
 package Net::EPP::Frame::Command::Transfer;
 use Net::EPP::Frame::Command::Transfer::Contact;
 use Net::EPP::Frame::Command::Transfer::Domain;
@@ -26,6 +21,10 @@ for the EPP C<E<lt>transferE<gt>> command.
 
 =head1 METHODS
 
+	$frame->setOp($op);
+
+Sets the op of the frame (i.e. C<request>, C<cancel>, C<approve> or C<reject>).
+
 =cut
 
 sub setOp {
@@ -33,25 +32,4 @@ sub setOp {
 	$self->getCommandNode->setAttribute('op', $op);
 }
 
-=pod
-
-=head1 AUTHOR
-
-CentralNic Ltd (http://www.centralnic.com/).
-
-=head1 COPYRIGHT
-
-This module is (c) 2016 CentralNic Ltd. This module is free software; you can
-redistribute it and/or modify it under the same terms as Perl itself.
-
-=head1 SEE ALSO
-
-=over
-
-=item * L<Net::EPP::Frame>
-
-=back
-
-=cut
-
 1;
