@@ -1,8 +1,3 @@
-# Copyright (c) 2016 CentralNic Ltd. All rights reserved. This program is
-# free software; you can redistribute it and/or modify it under the same
-# terms as Perl itself.
-# 
-# $Id: Response.pm,v 1.9 2011/07/04 09:48:51 gavin Exp $
 package Net::EPP::Frame::Response;
 use Net::EPP::ResponseCodes;
 use base qw(Net::EPP::Frame);
@@ -69,11 +64,6 @@ C<E<lt>commandE<gt>> element.
 This method returns the L<XML::LibXML::Element> object corresponding to the
 C<E<lt>resultE<gt>> element.
 
-	my $node = $frame->msg;
-
-This method returns the L<XML::LibXML::Element> object corresponding to the
-C<E<lt>msgE<gt>> element.
-
 	my $node = $frame->resData;
 
 This method returns the L<XML::LibXML::Element> object corresponding to the
@@ -136,25 +126,4 @@ sub msg {
 	return $msgs->shift->textContent if ($msgs->size == 1);
 }
 
-=pod
-
-=head1 AUTHOR
-
-CentralNic Ltd (http://www.centralnic.com/).
-
-=head1 COPYRIGHT
-
-This module is (c) 2016 CentralNic Ltd. This module is free software; you can
-redistribute it and/or modify it under the same terms as Perl itself.
-
-=head1 SEE ALSO
-
-=over
-
-=item * L<Net::EPP::Frame>
-
-=back
-
-=cut
-
 1;
