@@ -1,6 +1,3 @@
-# Copyright (c) 2016 CentralNic Ltd. All rights reserved. This program is
-# free software; you can redistribute it and/or modify it under the same
-# terms as Perl itself.
 package Net::EPP::Protocol;
 use bytes;
 use Carp;
@@ -35,14 +32,6 @@ servers.
 
 =head1 DESCRIPTION
 
-EPP is the Extensible Provisioning Protocol. EPP (defined in RFC 4930)
-is an application layer client-server protocol for the provisioning and
-management of objects stored in a shared central repository. Specified
-in XML, the protocol defines generic object management operations and an
-extensible framework that maps protocol operations to objects. As of
-writing, its only well-developed application is the provisioning of
-Internet domain names, hosts, and related contact details.
-
 This module implements functions that are common to both EPP clients and
 servers that implement the TCP transport as defined in RFC 4934. The
 main consumer of this module is currently L<Net::EPP::Client>.
@@ -111,7 +100,6 @@ sub get_frame {
 			}
 
 			return $xml;
-
 		}
 	}
 }
@@ -154,29 +142,4 @@ sub prep_frame {
 	return pack('N', length($xml) + 4).$xml;
 }
 
-=pod
-
-=head1 AUTHOR
-
-CentralNic Ltd (L<http://www.centralnic.com/>).
-
-=head1 COPYRIGHT
-
-This module is (c) 2016 CentralNic Ltd. This module is free software; you can
-redistribute it and/or modify it under the same terms as Perl itself.
-
-=head1 SEE ALSO
-
-=over
-
-=item * L<Net::EPP::Client>
-
-=item * RFCs 4930 and RFC 4934, available from L<http://www.ietf.org/>.
-
-=item * The CentralNic EPP site at L<http://www.centralnic.com/resellers/epp>.
-
-=back
-
-=cut
-
 1;
